/* sane - Scanner Access Now Easy.
   Copyright (C) 1997 Gordon Matzigkeit
   This file is part of the SANE package.

   SANE is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free
   Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   SANE is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with sane; see the file COPYING.  If not, write to the Free
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
#ifndef _PINT_H
#define _PINT_H

#include <sys/types.h>

/* FIXME - in the PINT sources, this is set to ifdef __NetBSD__ */
#include <sys/ioctl.h>

#ifdef HAVE_SYS_SCANIO_H
#include <sys/scanio.h>
#endif

typedef enum
  {
    OPT_NUM_OPTS = 0,

    OPT_MODE_GROUP,
    OPT_MODE,
    /* FIXME: eventually need to have both X and Y resolution. */
    OPT_RESOLUTION,

    OPT_GEOMETRY_GROUP,
    OPT_TL_X,			/* top-left x */
    OPT_TL_Y,			/* top-left y */
    OPT_BR_X,			/* bottom-right x */
    OPT_BR_Y,			/* bottom-right y */

    OPT_ENHANCEMENT_GROUP,
    OPT_BRIGHTNESS,
    OPT_CONTRAST,

    /* must come last: */
    NUM_OPTIONS
  }
PINT_Option;

typedef union
  {
    SANE_Word w;
    SANE_Word *wa;		/* word array */
    SANE_String s;
  }
Option_Value;

typedef struct PINT_Device
  {
    struct PINT_Device *next;
    SANE_Device sane;
    SANE_Range dpi_range;
    SANE_Range x_range;
    SANE_Range y_range;
    struct scan_io scanio; /* Scanner hardware state. */
  }
PINT_Device;

typedef struct PINT_Scanner
  {
    /* all the state needed to define a scan request: */
    struct PINT_Scanner *next;

    SANE_Option_Descriptor opt[NUM_OPTIONS];
    Option_Value val[NUM_OPTIONS];

    int scanning;
    SANE_Parameters params;

    int fd;			/* Device file descriptor */

    /* scanner dependent/low-level state: */
    PINT_Device *hw;
  }
PINT_Scanner;

#endif /* _PINT_H */
