.TH sane-mustek 5 "21 April 1997"
.IX sane-mustek
.SH NAME
sane-mustek - SANE backend for Mustek flatbed scanners
.SH DESCRIPTION
The
.B sane-mustek
library implements a SANE (Scanner Access Now Easy) backend that
provides access to Mustek flatbed scanners.  At present, the following
scanners are known positively to work with this backend:
.PP
.RS
Model:     SCSI id:    Firmware revision:
.br
---------- ----------- ------------------
.br
MFC-600S   MFC-06000CZ v1.01 and higher
.br
???        MSF-12000SP v1.00 and higher
.br
MFS-6000CX MSF-06000CZ v2.71 and higher
.RE
.PP
Note that this list includes both single- and three-pass scanners, so
in all likelihood, pretty much any Mustek flatbed scanner should work
with this backend.  If you own a Mustek scanner other than the ones
listed above, please let us know if your model works with this
backend.  To do this, send a mail with the relevant information for
your scanner to
.IR sane-devel@listserv.azstarnet.com .

.SH "DEVICE NAMES"
This backend expects device names of the form:
.PP
.RS
.IR special
.RE
.PP
Where
.I special
is the UNIX path-name for the special device that corresponds to the
scanner.  The special device name must be a generic SCSI device or a
symlink to such a device.  Under Linux, such a device name could be
.IR /dev/sga
or
.IR /dev/sge ,
for example.
.SH CONFIGURATION
The configuration file for this backend resides in
.IR @CONFIGDIR@/mustek.conf .
Its contents is a list of device names that correspond to Mustek
scanners.  Empty lines and lines starting with a hash mark (#) are
ignored.  A sample configuration file is shown below:
.PP
.RS
/dev/scanner
.br
# this is a comment
.br
/dev/sge
.RE
.SH SCSI ADAPTER TIPS
To keep scanning times to a minimum, it is strongly recommended to use
a large buffer size for the generic SCSI driver.  For example, under
Linux the system uses a buffer of size 32KB by default.  This works
but is about a factor of four slower than when using a size of 128KB.
For Linux, the size of this buffer is defined by macro
.B SG_BIG_BUFF
in header file
.IR /usr/include/sg.h .
After increasing this value to, say, (128*1024), it is necessary to
recompile the kernel and the Mustek backend.
.PP
The Mustek scanners are known to work with the following SCSI adapters:
.PP
.RS
.TP
Mustek-supplied 53c400/dtct436 ISA SCSI card
If your card is jumper-less (plug and pray) and the Linux kernel fails
to recognize your card, then you may need the patch
.I mustek-scsi-0.2.patch.gz
which is available at
.IR ftp://ftp.azstarnet.com/pub/linux/axp/sane/ .
Once the kernel detects the card, it should work all right.  However,
while it should work, do not expect good performance out of this
card---it has no interrupt line and therefore while a scan is in
progress, the system becomes almost unusable.
.TP
ncr810
When using this controller, be sure to configure the kernel such that
tagged command queueing is disabled, targets are not allowed to
disconnect, and make sure the SCSI timeout is reasonably big; the
default timeout for the Linux 2.0 kernels is 10 seconds, which is way too
low when scanning large area.
.TP
Adaptec 1505
When using this controller, be sure to configure the kernel such
that disconnection/reconnection is disabled, parity checking is enabled,
and synchronous transfers are disabled.
.RE
.PP
In general, we recommend to buy a separate (cheap) SCSI card for the
Mustek scanners (such as an ncr810 based card).  Otherwise, the
devices on the same SCSI bus as the scanner cannot be accessed while a
scan is in progress.
.SH FILES
.TP
.I @CONFIGDIR@/mustek.conf
The backend configuration file.
.TP
.I @LIBDIR@/libsane-mustek.a
The static library implementing this backend.
.TP
.I @LIBDIR@/libsane-mustek.so
The shared library implementing this backend (present on systems that
support dynamic loading).
.SH ENVIRONMENT
.TP
.B SANE_DEBUG_MUSTEK
If the library was compiled with debug support enabled, this
environment variable controls the debug level for this backend.  E.g.,
a value of 128 requests all debug output to be printed.  Smaller
levels reduce verbosity.
.TP
.B SANE_SANEI_SCSI
If the library was compiled with debug support enabled, this
environment variable controls the debug level for the generic SCSI I/O
subsystem.  E.g., a value of 128 requests all debug output to be
printed.  Smaller levels reduce verbosity.
.SH AUTHOR
David Mosberger
.SH BUGS
Transparency adapter and automatic document feeder support is severly
lacking (due to absence of equipment to test this with).

There seems to be a performance bug that makes scanning on (some)
three-pass scanner slower than necessary.
