/* sane - Scanner Access Now Easy.
   Copyright (C) 1996, 1997 David Mosberger-Tang and Andreas Beck
   This file is part of the SANE package.

   SANE is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   SANE is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with sane; see the file COPYING.  If not, write to the Free
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
   USA. */

#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>

#ifndef __GNUC__
  static int max_level = 0;
#endif

void
sanei_init_debug (const char * backend, int * var)
{
  char ch, buf[256] = "SANE_DEBUG_";
  const char * val;
  int i;

  *var = 0;

  for (i = 11; (ch = backend[i - 11]) != 0; ++i)
    {
      if (i >= sizeof (buf) - 1)
	break;
      buf[i] = toupper(ch);
    }
  buf[i] = '\0';

  val = getenv (buf);
  if (!val)
    return;

  *var = atoi (val);

#ifndef __GNUC__
  if (*var > max_level)
    max_level = *var;
#endif  

  fprintf (stderr, "[sanei_init_debug]: Setting debug level of %s to %d.\n",
	   backend, *var);
}

#ifndef __GNUC__

#include <stdarg.h>

void
sanei_debug (int level, const char *fmt, ...)
{
  va_list ap;

  if (max_level >= level)
    {
      va_start (ap, fmt);
      vfprintf (stderr, fmt, ap);
      va_end (ap);
    }
}

#endif /* !__GNUC__ */
